@@ -30,7 +30,7 @@ public:
 
     virtual void loadAccount(ImapAccount *account) const;
 
-    QString rootRemoteId() const;
+    Q_REQUIRED_RESULT QString rootRemoteId() const;
     virtual void renameRootCollection(const QString &newName);
 
     virtual void clearCachedPassword();
@@ -56,4 +56,3 @@ protected:
     mutable QString m_password;
     mutable QString m_customSievePassword;
 };
-
